firecraft
library
A Very Good Project created by Very Good CLI.
Classes
-
Firecraft
-
A utility class that provides a simplified interface for interacting with
Cloud Firestore.
-
PaginatedResult<T>
-
A generic class that represents a paginated result set from Firestore
queries.
Typedefs
-
FromJson<T>
= T Function(Json json)
-
Converts raw Firestore document data into a typed model.
-
Json
= Map<String, dynamic>
-
JSON-shaped map used throughout the Firestore API.
-
QueryBuilder
= Query<Json> Function(CollectionReference<Json>)
-
Builds a
Query from a CollectionReference.